==> upload-api-client-internal-2.55.0.tgz: package/src/models/BeginMultipartUploadRequestV2.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { FileMetadata } from "./FileMetadata";
import type { FilePathDefinition } from "./FilePathDefinition";
import type { FileTagName } from "./FileTagName";
import type { MimeType } from "./MimeType";
import type { MultipartUploadProtocol } from "./MultipartUploadProtocol";
import type { OriginalFileName } from "./OriginalFileName";
import type { SizeInBytes } from "./SizeInBytes";

/**
 * Request body for BeginMultipartUpload.
 */
export type BeginMultipartUploadRequestV2 = {
  /**
   * An arbitrary JSON object to store against the file as metadata.
   *
   * You can retrieve this later via a GetFileDetails request.
   */
  metadata?: FileMetadata;
  /**
   * The file's MIME type.
   */
  mime?: MimeType;
  /**
   * The file's original name on the user's device.
   */
  originalFileName?: OriginalFileName;
  /**
   * The path to upload the file to.
   */
  path?: FilePathDefinition;
  /**
   * Multipart upload protocol version to use.
   *
   * The latest Upload SDKs use the latest supported version.
   *
   * Recommended: "1.1"
   *
   * Default: "1.0"
   */
  protocol?: MultipartUploadProtocol;
  /**
   * The size of the file in bytes.
   */
  size: SizeInBytes;
  /**
   * The file tags to store against the file.
   *
   * When you associate file tags with a file, Upload checks which rules match the tags (if any) and applies those rules to the upload request:
   *
   * Rules can include max file size checks, traffic limit checks, rate limit checks, and so forth. These are configured in the Upload Dashboard.
   */
  tags?: Array<FileTagName>;
};

==> upload-api-client-internal-2.64.0.tgz: package/src/models/BeginMultipartUploadRequestV2.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { FileMetadata } from "./FileMetadata";
import type { FilePathDefinition } from "./FilePathDefinition";
import type { FileTagName } from "./FileTagName";
import type { MimeType } from "./MimeType";
import type { MultipartUploadProtocol } from "./MultipartUploadProtocol";
import type { OriginalFileName } from "./OriginalFileName";
import type { SizeInBytes } from "./SizeInBytes";

/**
 * Request body for BeginMultipartUpload.
 */
export type BeginMultipartUploadRequestV2 = {
  /**
   * Arbitrary JSON to store against the file as metadata.
   *
   * You can retrieve this later via a GetFileDetails request.
   */
  metadata?: FileMetadata;
  /**
   * The file's MIME type.
   */
  mime?: MimeType;
  /**
   * The file's original name on the user's device.
   */
  originalFileName?: OriginalFileName;
  /**
   * The path to upload the file to.
   */
  path?: FilePathDefinition;
  /**
   * Multipart upload protocol version to use.
   *
   * The latest Upload SDKs use the latest supported version.
   *
   * Recommended: "1.1"
   *
   * Default: "1.0"
   */
  protocol?: MultipartUploadProtocol;
  /**
   * The size of the file in bytes.
   */
  size: SizeInBytes;
  /**
   * The file tags to store against the file.
   *
   * When you associate file tags with a file, Upload checks which rules match the tags (if any) and applies those rules to the upload request:
   *
   * Rules can include max file size checks, traffic limit checks, rate limit checks, and so forth. These are configured in the Upload Dashboard.
   */
  tags?: Array<FileTagName>;
};
